@@ -1,6 +1,11 @@
 #include "asclock.h"
 #include <X11/X.h>
 #include <X11/Intrinsic.h>
+#ifdef ASCLOCK_GNOME
+/* needed for i18n stuff */
+#include <config.h>
+#include <gnome.h>
+#endif
 #include <gdk/gdkx.h>
 
 /* the xpm's */
@@ -428,7 +433,6 @@ int main( int argc, char *argv[] )
     /* GtkWidget is the storage type for widgets */
     GdkWindowPrivate *clk;
     GdkColor colour;
-    GdkColormap *cmap;
 
     bindtextdomain(PACKAGE, GNOMELOCALEDIR);
     textdomain(PACKAGE);
