@@ -20,6 +20,13 @@
 #include "gwmdesktop.h"
 
 
+#define CONFIG_OBOX_BORDER 6
+#define CONFIG_OBOX_SPACING 8
+#define CONFIG_IBOX_BORDER 6
+#define CONFIG_IBOX_SPACING 4
+#define CONFIG_ITEM_BORDER 0
+#define CONFIG_ITEM_SPACING 4
+  
 
 /* --- prototypes --- */
 static void	gp_init_gui		(void);
@@ -34,7 +41,8 @@ static gboolean	gp_task_notifier	(gpointer	    func_data,
 					 GwmhTaskInfoMask   imask);
 static void	gp_about		(void);
 static void	gp_config_popup		(void);
-static gpointer	gp_config_find_value	(const gchar *path);
+static gpointer	gp_config_find_value	(const gchar       *path,
+					 gboolean           tmp_value);
 static void	gp_load_config		(const gchar	   *privcfgpath);
 static gboolean	gp_save_session		(gpointer	    func_data,
 					 const gchar	   *privcfgpath,
@@ -52,63 +60,87 @@ static GtkWidget	*gp_desk_widget[MAX_DESKTOPS] = { NULL, };
 static guint             gp_n_desk_widgets = 0;
 static GdkWindow	*gp_atom_window = NULL;
 static GtkOrientation    gp_orientation = GTK_ORIENTATION_HORIZONTAL;
+/* static guint             gp_panel_size = 12; */
 static guint		 GP_TYPE_HBOX = 0;
 static guint		 GP_TYPE_VBOX = 0;
 static guint		 GP_ARROW_DIR = 0;
 static gchar		*DESK_GUIDE_NAME = NULL;
 
 static ConfigItem gp_config_items[] = {
-  CONFIG_SECTION (tooltip_settings,			 	N_ ("Tooltips")),
-  CONFIG_BOOL (desktips,	TRUE,
-	       N_ ("Enable Desktop Names")),
-  CONFIG_RANGE (desktips_delay,	10,	1,	5000,
-		N_ ("Desktop Name Popup Delay [ms]")),
-  CONFIG_BOOL (tooltips,	TRUE,
-	       N_ ("Enable Tooltips")),
-  CONFIG_RANGE (tooltips_delay,	500,	1,	5000,
-		N_ ("Tooltips Delay [ms]")),
-  CONFIG_SECTION (layout,				  	N_ ("Layout")),
+  CONFIG_PAGE (N_ ("Display")),
+  CONFIG_SECTION (sect_layout,				  	N_ ("Layout")),
   CONFIG_BOOL (switch_arrow,	FALSE,
-	       N_ ("Switch Arrow")),
-  CONFIG_BOOL (current_only,	FALSE,
-	       N_ ("Show only current Desktop")),
+	       N_ ("Switch tasklist arrow")),
   CONFIG_BOOL (show_pager,	TRUE,
-	       N_ ("Show Desktop Pager")),
+	       N_ ("Show desktop pager")),
+  CONFIG_BOOL (current_only,	FALSE,
+	       N_ ("Only show current desktop in pager")),
+  CONFIG_BOOL (raise_grid,		FALSE,
+	       N_ ("Raise area grid over tasks")),
+  CONFIG_SECTION (sect_tooltips,			 	N_ ("Tooltips")),
+  CONFIG_BOOL (tooltips,	TRUE,
+	       N_ ("Show Desk-Guide tooltips")),
+  CONFIG_RANGE (tooltips_delay,	500,	1,	5000,
+		N_ ("Desk-Guide tooltip delay [ms]")),
+  CONFIG_BOOL (desktips,	TRUE,
+	       N_ ("Show desktop name tooltips")),
+  CONFIG_RANGE (desktips_delay,	10,	1,	5000,
+		N_ ("Desktop name tooltip delay [ms]")),
   
   CONFIG_PAGE (N_ ("Tasks")),
-  CONFIG_SECTION (task_visibility,			  	N_ ("Visibility")),
+  CONFIG_SECTION (sect_task_visibility,			  	N_ ("Visibility")),
   CONFIG_BOOL (show_hidden_tasks,	TRUE,
-	       N_ ("Show `HIDDEN' Tasks")),
+	       N_ ("Show hidden tasks (HIDDEN)")),
   CONFIG_BOOL (show_shaded_tasks,	TRUE,
-	       N_ ("Show `SHADED' Tasks")),
+	       N_ ("Show shaded tasks (SHADED)")),
   CONFIG_BOOL (show_skip_winlist,	FALSE,
-	       N_ ("Show `SKIP-WINLIST' Tasks")),
+	       N_ ("Show tasks which hide from window list (SKIP-WINLIST)")),
   CONFIG_BOOL (show_skip_taskbar,	FALSE,
-	       N_ ("Show `SKIP-TASKBAR' Tasks")),
-  CONFIG_SECTION (cosmetics,				  	N_ ("Cosmetics")),
-  CONFIG_BOOL (raise_grid,		FALSE,
-	       N_ ("Raise Area Grid Above Tasks")),
-  /*  CONFIG_SECTION ("", NULL), */
+	       N_ ("Show tasks which hide from taskbar (SKIP-TASKBAR)")),
+  /*  CONFIG_SECTION (sect_null_1, NULL), */
   
   CONFIG_PAGE (N_ ("Geometry")),
-  CONFIG_SECTION (horizontal,                        	     	N_ ("Horizontal Layout")),
-  CONFIG_RANGE (area_height,	44,	4,	256,
+  CONFIG_SECTION (sect_horizontal,                     	     	N_ ("Horizontal Layout")),
+  CONFIG_RANGE (area_height,	44,	4,	1024,
 		N_ ("Desktop Height [pixels]")),
+  /*
+    CONFIG_BOOL (abandon_area_height,		TRUE,
+	       N_ ("Override desktop height with panel size")),
+  */
   CONFIG_BOOL (div_by_vareas,		TRUE,
-	       N_ ("Divide Height By Number Of Vertical Areas")),
-  CONFIG_SECTION (vertical,                        	     	N_ ("Vertical Layout")),
-  CONFIG_RANGE (area_width,	44,	4,	256,
-		N_ ("Desktop width [pixels]")),
+	       N_ ("Divide height by number of vertical areas")),
+  CONFIG_RANGE (row_stackup,	1,	1,	64,
+		N_ ("Rows of Desktops")),
+  CONFIG_BOOL (div_by_nrows,		TRUE,
+	       N_ ("Divide height by number of rows")),
+  CONFIG_SECTION (sect_vertical,                       	     	N_ ("Vertical Layout")),
+  CONFIG_RANGE (area_width,	44,	4,	1024,
+		N_ ("Desktop Width [pixels]")),
+  /*
+    CONFIG_BOOL (abandon_area_width,		TRUE,
+	       N_ ("Override desktop width with panel size")),
+  */
   CONFIG_BOOL (div_by_hareas,		TRUE,
-	       N_ ("Divide Width By Number Of Horizontal Areas")),
+	       N_ ("Divide width by number of horizontal areas")),
+  CONFIG_RANGE (col_stackup,	1,	1,	64,
+		N_ ("Columns of Desktops")),
+  CONFIG_BOOL (div_by_ncols,		TRUE,
+	       N_ ("Divide width by number of columns")),
 
-  CONFIG_PAGE (N_ ("Advanced Options")),
+  CONFIG_PAGE (N_ ("Advanced")),
+  CONFIG_SECTION (sect_drawing,                   	     	N_ ("Drawing")),
   CONFIG_BOOL (double_buffer,	TRUE,
-	       N_ ("Draw Desktops Double Buffered")),
-  CONFIG_SECTION (bug_fixes,                        	     	N_ ("Bug Fixes")),
-  CONFIG_BOOL (skip_movement_offset,		FALSE,
-	       N_ ("Window Manager Moves Decoration Window Instead\n"
-		   "(AfterStep, Enlightenment, FVWM, IceWM)")),
+	       N_ ("Draw desktops double-buffered (recommended)")),
+  CONFIG_SECTION (sect_workarounds,         	     	N_ ("Window Manager Workarounds")),
+  CONFIG_BOOL (skip_movement_offset,		TRUE,
+	       N_ ("Window manager moves decoration window instead\n"
+		   "(AfterStep, Enlightenment, FVWM, IceWM, SawMill)")),
+  CONFIG_BOOL (unified_areas,			TRUE,
+	       N_ ("Window manager changes active area on all desktops\n"
+		   "(FVWM, SawMill)")),
+  CONFIG_BOOL (violate_client_msg,			TRUE,
+	       N_ ("Window manager expects pager to modify area+desktop properties directly\n"
+		   "(Enlightenment, FVWM, SawMill)")),
 };
 static guint  gp_n_config_items = (sizeof (gp_config_items) /
 				   sizeof (gp_config_items[0]));
@@ -192,6 +224,8 @@ main (gint   argc,
 		  "signal::change-orient", fixme_applet_widget_get_panel_orient, NULL,
 		  "signal::change-orient", gp_destroy_gui, NULL,
 		  "signal::change-orient", gp_init_gui, NULL,
+		  "signal::change-size", gp_destroy_gui, NULL,
+		  "signal::change-size", gp_init_gui, NULL,
 		  "object_signal::save-session", gp_save_session, NULL,
 		  "signal::destroy", gtk_main_quit, NULL,
 		  NULL);
@@ -239,7 +273,7 @@ gp_load_config (const gchar *privcfgpath)
 {
   static guint loaded = FALSE;
   guint i;
-  gchar *section = "general";
+  gchar *section = "sect_general";
   
   if (loaded)
     return;
@@ -283,7 +317,8 @@ gp_load_config (const gchar *privcfgpath)
 }
 
 static gpointer
-gp_config_find_value (const gchar *path)
+gp_config_find_value (const gchar *path,
+		      gboolean     tmp_value)
 {
   guint i;
   
@@ -292,7 +327,7 @@ gp_config_find_value (const gchar *path)
       ConfigItem *item = gp_config_items + i;
       
       if (path == item->path)
-	return item->value;
+	return tmp_value ? item->tmp_value : item->value;
     }
   
   g_warning (G_GNUC_PRETTY_FUNCTION "(): unable to find config value for <%s>", path);
@@ -306,7 +341,7 @@ gp_save_session (gpointer     func_data,
 		 const gchar *globcfgpath)
 {
   guint i;
-  gchar *section = "general";
+  gchar *section = "sect_general";
   
   gnome_config_push_prefix (privcfgpath);
   
@@ -379,8 +414,6 @@ gp_desk_notifier (gpointer	   func_data,
 		  GwmhDesk	  *desk,
 		  GwmhDeskInfoMask change_mask)
 {
-  guint i;
-
   if (change_mask & GWMH_DESK_INFO_BOOTUP)
     {
       gp_destroy_gui ();
@@ -389,15 +422,17 @@ gp_desk_notifier (gpointer	   func_data,
   else
     {
       /* keep number of desktop widgets in sync with desk */
-      for (i = desk->n_desktops; i < gp_n_desk_widgets; i++)
-	gtk_widget_destroy (gp_desk_widget[i]);
-      gp_create_desk_widgets ();
+      if (change_mask & (GWMH_DESK_INFO_DESKTOP_NAMES |
+			 GWMH_DESK_INFO_N_DESKTOPS |
+			 GWMH_DESK_INFO_N_AREAS |
+			 GWMH_DESK_INFO_BOOTUP))
+	gp_create_desk_widgets ();
       
       if (gp_n_desk_widgets && BOOL_CONFIG (current_only))
 	gwm_desktop_set_index (GWM_DESKTOP (gp_desk_widget[0]),
 			       desk->current_desktop);
     }
-
+  
   return TRUE;
 }
 
@@ -433,17 +468,40 @@ gp_create_desk_widgets (void)
   if (N_DESKTOPS > MAX_DESKTOPS)
     g_error ("MAX_DESKTOPS limit reached, adjust source code");
 
+  /* some gwmh configuration hacks ;( */
+  gwmh_desk_set_hack_values (BOOL_CONFIG (unified_areas),
+			     BOOL_CONFIG (violate_client_msg));
+
   if (!gp_desk_box)
     return;
 
   /* configure Desktop widget class for us */
-  area_size = (gp_orientation == GTK_ORIENTATION_HORIZONTAL
-	       ? RANGE_CONFIG (area_height)
-	       : RANGE_CONFIG (area_width));
-  if (gp_orientation == GTK_ORIENTATION_HORIZONTAL && BOOL_CONFIG (div_by_vareas))
-    area_size /= (gdouble) N_VAREAS;
-  if (gp_orientation == GTK_ORIENTATION_VERTICAL && BOOL_CONFIG (div_by_hareas))
-    area_size /= (gdouble) N_HAREAS;
+  if (gp_orientation == GTK_ORIENTATION_HORIZONTAL)
+    {
+      /*
+	if (BOOL_CONFIG (abandon_area_height))
+	area_size = gp_panel_size;
+	else
+      */
+      area_size = RANGE_CONFIG (area_height);
+      if (BOOL_CONFIG (div_by_vareas))
+	area_size /= (gdouble) N_VAREAS;
+      if (BOOL_CONFIG (div_by_nrows))
+	area_size /= (gdouble) RANGE_CONFIG (row_stackup);
+    }
+  else /* gp_orientation == GTK_ORIENTATION_VERTICAL */
+    {
+      /*
+	if (BOOL_CONFIG (abandon_area_width))
+	area_size = gp_panel_size;
+	else
+      */
+      area_size = RANGE_CONFIG (area_width);
+      if (BOOL_CONFIG (div_by_hareas))
+	area_size /= (gdouble) N_HAREAS;
+      if (BOOL_CONFIG (div_by_ncols))
+	area_size /= (gdouble) RANGE_CONFIG (col_stackup);
+    }
   gwm_desktop_class_config (gtk_type_class (GWM_TYPE_DESKTOP),
 			    BOOL_CONFIG (double_buffer),
 			    gp_orientation,
@@ -452,22 +510,47 @@ gp_create_desk_widgets (void)
 			    BOOL_CONFIG (skip_movement_offset));
 
   gp_n_desk_widgets = 0;
+  gtk_container_forall (GTK_CONTAINER (gp_desk_box), (GtkCallback) gtk_widget_destroy, NULL);
   if (BOOL_CONFIG (show_pager))
     {
+      GtkWidget *desk_column = NULL;
+      guint n_desks_per_column;
       guint i, max = BOOL_CONFIG (current_only) ? 1 : N_DESKTOPS;
       
+      if (gp_orientation == GTK_ORIENTATION_HORIZONTAL)
+	{
+	  n_desks_per_column = RANGE_CONFIG (row_stackup);
+	  n_desks_per_column = (N_DESKTOPS + n_desks_per_column - 1) / n_desks_per_column;
+	}
+      else
+	n_desks_per_column = RANGE_CONFIG (col_stackup);
+      
       for (i = 0; i < max; i++)
-	if (!gp_desk_widget[i])
-	  {
-	    gp_desk_widget[i] = gwm_desktop_new (max > 1 ? i : CURRENT_DESKTOP,
-						 gp_desktips);
-	    gtk_widget_set (gp_desk_widget[i],
-			    "parent", gp_desk_box,
-			    "visible", TRUE,
-			    "signal::check-task", gp_check_task_visible, NULL,
-			    "signal::destroy", gtk_widget_destroyed, &gp_desk_widget[i],
-			    NULL);
-	  }
+	{
+	  GtkWidget *alignment;
+	  
+	  if (!desk_column)
+	    desk_column = gtk_widget_new (GTK_TYPE_HBOX,
+					  "visible", TRUE,
+					  "spacing", 0,
+					  "parent", gp_desk_box,
+					  NULL);
+	  gp_desk_widget[i] = gwm_desktop_new (max > 1 ? i : CURRENT_DESKTOP, gp_desktips);
+	  alignment = gtk_widget_new (GTK_TYPE_ALIGNMENT,
+				      "visible", TRUE,
+				      "xscale", 0.0,
+				      "yscale", 0.0,
+				      NULL);
+	  gtk_widget_set (gp_desk_widget[i],
+			  "parent", alignment,
+			  "visible", TRUE,
+			  "signal::check-task", gp_check_task_visible, NULL,
+			  "signal::destroy", gtk_widget_destroyed, &gp_desk_widget[i],
+			  NULL);
+	  gtk_box_pack_start (GTK_BOX (desk_column), alignment, FALSE, FALSE, 0);
+	  if ((i + 1) % n_desks_per_column == 0)
+	    desk_column = NULL;
+	}
       gp_n_desk_widgets = i;
     }
 }
@@ -542,11 +625,13 @@ gp_widget_ignore_button (GtkWidget      *widget,
 static void 
 gp_init_gui (void)
 {
+  /*  static guint panel_sizes[] = { 24, 48, 64, 80 }; */
   GtkWidget *button, *abox;
   gboolean arrow_at_end = FALSE;
   GtkWidget *main_box;
   
   gtk_widget_set_usize (gp_container, 0, 0);
+  /*  gp_panel_size = panel_sizes[applet_widget_get_panel_size (APPLET_WIDGET (gp_applet))]; */
   switch (applet_widget_get_panel_orient (APPLET_WIDGET (gp_applet)))
     {
     case ORIENT_UP:
@@ -618,7 +703,7 @@ gp_init_gui (void)
 
   /* provide desktop widget container
    */
-  gp_desk_box = gtk_widget_new (GP_TYPE_HBOX,
+  gp_desk_box = gtk_widget_new (GTK_TYPE_VBOX,
 				"visible", TRUE,
 				"spacing", 0,
 				"signal::destroy", gtk_widget_destroyed, &gp_desk_box,
@@ -707,6 +792,19 @@ gp_about (void)
   gdk_window_raise (dialog->window);
 }
 
+static void
+gp_config_check (GtkWidget *widget)
+{
+  GtkWidget *toplevel = gtk_widget_get_toplevel (widget);
+
+  /*
+    gtk_widget_set_sensitive (CONFIG_WIDGET (toplevel, area_height),
+			    !BOOL_TMP_CONFIG (abandon_area_height));
+  gtk_widget_set_sensitive (CONFIG_WIDGET (toplevel, area_width),
+			    !BOOL_TMP_CONFIG (abandon_area_width));
+  */
+}
+
 static void
 gp_config_toggled (GtkToggleButton *button,
 		   ConfigItem      *item)
@@ -719,18 +817,21 @@ static inline GtkWidget*
 gp_config_add_boolean (GtkWidget  *vbox,
 		       ConfigItem *item)
 {
-  GtkWidget *widget;
+  GtkWidget *widget, *toplevel = gtk_widget_get_toplevel (vbox);
   
   widget = gtk_widget_new (GTK_TYPE_CHECK_BUTTON,
 			   "visible", TRUE,
 			   "label", _ (item->name),
 			   "active", GPOINTER_TO_INT (item->value),
+			   "border_width", CONFIG_ITEM_BORDER,
 			   "signal::toggled", gp_config_toggled, item,
+			   "object_signal_after::toggled", gp_config_check, toplevel,
 			   NULL);
   gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 0);
   gtk_widget_set (GTK_BIN (widget)->child,
 		  "xalign", 0.0,
 		  NULL);
+  gtk_object_set_data (GTK_OBJECT (toplevel), item->path, widget);
   
   return widget;
 }
@@ -748,7 +849,7 @@ gp_config_add_range (GtkWidget  *vbox,
 		     ConfigItem *item)
 {
   GtkObject *adjustment;
-  GtkWidget *hbox, *label, *spinner;
+  GtkWidget *hbox, *label, *spinner, *toplevel = gtk_widget_get_toplevel (vbox);
   
   adjustment = gtk_adjustment_new (GPOINTER_TO_UINT (item->tmp_value),
 				   item->min,
@@ -756,10 +857,10 @@ gp_config_add_range (GtkWidget  *vbox,
 				   1, 1,
 				   (item->max - item->min) / 10);
   hbox = gtk_widget_new (GTK_TYPE_HBOX,
-			 "homogeneous", TRUE,
+			 "homogeneous", FALSE,
 			 "visible", TRUE,
-			 "spacing", GNOME_PAD_SMALL,
-			 "border_width", GNOME_PAD_SMALL,
+			 "spacing", CONFIG_ITEM_SPACING,
+			 "border_width", CONFIG_ITEM_BORDER,
 			 NULL);
   label = gtk_widget_new (GTK_TYPE_LABEL,
 			  "visible", TRUE,
@@ -768,14 +869,18 @@ gp_config_add_range (GtkWidget  *vbox,
 			  "parent", hbox,
 			  NULL);
   spinner = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 0, 0);
-  gtk_widget_show (spinner);
+  gtk_widget_set (spinner,
+		  "visible", TRUE,
+		  "width", 80,
+		  NULL);
   gtk_object_set_user_data (GTK_OBJECT (adjustment), spinner);
   gtk_box_pack_end (GTK_BOX (hbox), spinner, FALSE, TRUE, 0);
-  gtk_signal_connect (adjustment,
-		      "value_changed",
-		      GTK_SIGNAL_FUNC (gp_config_value_changed),
-		      item);
+  gtk_object_set (adjustment,
+		  "signal::value_changed", gp_config_value_changed, item,
+		  "object_signal_after::value_changed", gp_config_check, toplevel,
+		  NULL);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
+  gtk_object_set_data (GTK_OBJECT (toplevel), item->path, hbox);
   
   return hbox;
 }
@@ -796,17 +901,21 @@ gp_config_add_section (GtkBox      *parent,
       box = gtk_widget_new (GTK_TYPE_VBOX,
 			    "visible", TRUE,
 			    "parent", widget,
+			    "border_width", CONFIG_IBOX_BORDER,
+			    "spacing", CONFIG_IBOX_SPACING,
 			    NULL);
     }
   else
     {
       box = gtk_widget_new (GTK_TYPE_VBOX,
 			    "visible", TRUE,
+			    "border_width", 0,
+			    "spacing", CONFIG_OBOX_SPACING,
 			    NULL);
       widget = box;
     }
 
-  gtk_box_pack_start (parent, widget, TRUE, TRUE, 0);
+  gtk_box_pack_start (parent, widget, FALSE, TRUE, 0);
   
   return box;
 }
@@ -827,7 +936,6 @@ gp_config_create_page (GSList		*item_slist,
       GSList *node = item_slist;
       
       item_slist = node->next;
-      g_slist_free_1 (node);
       
       page_name = _ (item->name);
     }
@@ -836,19 +944,18 @@ gp_config_create_page (GSList		*item_slist,
   
   page = gtk_widget_new (GTK_TYPE_VBOX,
 			 "visible", TRUE,
-			 "border_width", GNOME_PAD_SMALL,
-			 "spacing", GNOME_PAD_SMALL,
+			 "border_width", CONFIG_OBOX_BORDER,
+			 "spacing", CONFIG_OBOX_SPACING,
 			 NULL);
+  gnome_property_box_append_page (pbox, page, gtk_label_new (_ (page_name)));
   
   while (item_slist)
     {
-      GSList *node = item_slist;
-      ConfigItem *item = node->data;
+      ConfigItem *item = item_slist->data;
       
       if (!item->path)						/* page */
 	break;
-      item_slist = node->next;
-      g_slist_free_1 (node);
+      item_slist = item_slist->next;
       
       if (item->min == -2 && item->max == -2)			/* section */
 	vbox = gp_config_add_section (GTK_BOX (page), _ (item->name));
@@ -866,8 +973,6 @@ gp_config_create_page (GSList		*item_slist,
 	}
     }
   
-  gnome_property_box_append_page (pbox, page, gtk_label_new (_ (page_name)));
-  
   return item_slist;
 }
 
@@ -880,12 +985,13 @@ gp_config_popup (void)
   
   if (!dialog)
     {
-      GSList *slist = NULL;
+      GSList *fslist, *slist = NULL;
       guint i;
       
       for (i = 0; i < gp_n_config_items; i++)
 	slist = g_slist_prepend (slist, gp_config_items + i);
       slist = g_slist_reverse (slist);
+      fslist = slist;
       
       dialog = gnome_property_box_new ();
       gtk_widget_set (dialog,
@@ -894,15 +1000,15 @@ gp_config_popup (void)
 		      "signal::apply", gp_config_apply_tmp_values, NULL,
 		      "signal::apply", gp_init_gui, NULL,
 		      "signal::destroy", gp_config_reset_tmp_values, NULL,
+		      "signal::destroy", gtk_widget_destroyed, &dialog,
 		      NULL);
       
       while (slist)
 	slist = gp_config_create_page (slist, GNOME_PROPERTY_BOX (dialog));
-      
-      gtk_widget_set (dialog,
-		      "signal::destroy", gtk_widget_destroyed, &dialog,
-		      NULL);
+      g_slist_free (fslist);
+
       gtk_quit_add_destroy (1, GTK_OBJECT (dialog));
+      gp_config_check (dialog);
     }
   
   gtk_widget_show (dialog);
