@@ -79,8 +79,7 @@ static void about_cb (AppletWidget *widget, gpointer data)
 			"(C) 1999",
 			authors,
 			_("Released under the GNU general public license.\n"
-			"Mounts and Unmounts drives."
-			"."),
+			"Mounts and Unmounts drives."),
 			NULL);
 	gtk_widget_show (about);
 }
@@ -120,7 +119,7 @@ static gint device_is_in_mountlist(DriveData *dd)
 	gchar buf[201];
 	gint found = FALSE;
 
-	buf[201] = '\0';
+	buf[200] = '\0';
 
 	fp = popen(command_line, "r");
 
