@@ -13,7 +13,7 @@
 
 BEGIN_GNOME_DECLS
 
-GtkWidget * make_clock_applet(const gchar *param);
+GtkWidget * make_clock_applet(const gchar *goad_id);
 
 END_GNOME_DECLS
 
