@@ -257,8 +257,11 @@ void close_cb( GtkWidget *widget, void *data )
 
 void properties(AppletWidget *applet, gpointer data)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	GtkWidget *frame, *label;
 
+	help_entry.name = gnome_app_id;
+
 	if( propbox )
 		return;
 
@@ -291,5 +294,9 @@ void properties(AppletWidget *applet, gpointer data)
 	gtk_signal_connect( GTK_OBJECT(propbox),
 		"destroy", GTK_SIGNAL_FUNC(close_cb), NULL );
 
+	gtk_signal_connect( GTK_OBJECT(propbox),
+		"help", GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+			    &help_entry );
+
 	gtk_widget_show_all(propbox);
 }
