@@ -30,16 +30,8 @@ struct _DrawerWidget
 {
 	BasePWidget		basep;
 
-	GtkWidget		*panel;
-	GtkWidget		*table;
-	GtkWidget		*handle_n;
-	GtkWidget		*handle_e;
-	GtkWidget		*handle_w;
-	GtkWidget		*handle_s;
-	
-	GtkWidget		*frame;
-
 	DrawerState		state;
+	int			temp_hidden;
 	PanelOrientType		orient;
 };
 
